==> rabbitmq-server-2.8.2.tar.gz: rabbitmq-server-2.8.2/plugins-src/rabbitmq-federation/src/rabbit_federation_link_sup_sup.erl <==
%% The contents of this file are subject to the Mozilla Public License
%% Version 1.1 (the "License"); you may not use this file except in
%% compliance with the License. You may obtain a copy of the License
%% at http://www.mozilla.org/MPL/
%%
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and
%% limitations under the License.
%%
%% The Original Code is RabbitMQ Federation.
%%
%% The Initial Developer of the Original Code is VMware, Inc.
%% Copyright (c) 2007-2011 VMware, Inc.  All rights reserved.
%%

-module(rabbit_federation_link_sup_sup).

-behaviour(mirrored_supervisor).

-include_lib("rabbit_common/include/rabbit.hrl").
-define(SUPERVISOR, rabbit_federation_link_sup_sup).

-export([start_link/0, start_child/2, stop_child/1]).

-export([init/1]).

%%----------------------------------------------------------------------------

start_link() ->
    mirrored_supervisor:start_link({local, ?SUPERVISOR},
                                   ?SUPERVISOR, ?MODULE, []).

start_child(Id, Args) ->
    {ok, Pid} = mirrored_supervisor:start_child(
                  ?SUPERVISOR,
                  {Id, {rabbit_federation_link_sup, start_link, [Args]},
                   transient, ?MAX_WAIT, supervisor,
                   [rabbit_federation_link_sup]}),
    {ok, Pid}.

stop_child(Id) ->
    ok = mirrored_supervisor:terminate_child(?SUPERVISOR, Id),
    ok = mirrored_supervisor:delete_child(?SUPERVISOR, Id),
    ok.

%%----------------------------------------------------------------------------

init([]) ->
    {ok, {{one_for_one, 3, 10}, []}}.

==> rabbitmq-server_3.0.0.orig.tar.gz: rabbitmq-server-3.0.0/plugins-src/rabbitmq-federation/src/rabbit_federation_link_sup_sup.erl <==
%% The contents of this file are subject to the Mozilla Public License
%% Version 1.1 (the "License"); you may not use this file except in
%% compliance with the License. You may obtain a copy of the License
%% at http://www.mozilla.org/MPL/
%%
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and
%% limitations under the License.
%%
%% The Original Code is RabbitMQ Federation.
%%
%% The Initial Developer of the Original Code is VMware, Inc.
%% Copyright (c) 2007-2011 VMware, Inc.  All rights reserved.
%%

-module(rabbit_federation_link_sup_sup).

-behaviour(mirrored_supervisor).

-include_lib("rabbit_common/include/rabbit.hrl").
-define(SUPERVISOR, rabbit_federation_link_sup_sup).

-export([start_link/0, start_child/1, adjust/1, stop_child/1]).

-export([init/1]).

%%----------------------------------------------------------------------------

start_link() ->
    mirrored_supervisor:start_link({local, ?SUPERVISOR},
                                   ?SUPERVISOR, ?MODULE, []).

start_child(X) ->
    {ok, _Pid} = mirrored_supervisor:start_child(
                   ?SUPERVISOR,
                   {id(X), {rabbit_federation_link_sup, start_link, [X]},
                    transient, ?MAX_WAIT, supervisor,
                    [rabbit_federation_link_sup]}).

adjust(Reason) ->
    [rabbit_federation_link_sup:adjust(Pid, Id, Reason) ||
        {Id, Pid, _, _} <- mirrored_supervisor:which_children(?SUPERVISOR)],
    ok.

stop_child(X) ->
    ok = mirrored_supervisor:terminate_child(?SUPERVISOR, id(X)),
    ok = mirrored_supervisor:delete_child(?SUPERVISOR, id(X)).

%%----------------------------------------------------------------------------

init([]) ->
    {ok, {{one_for_one, 3, 10}, []}}.

id(X) ->
    X#exchange{scratches = undefined}.
